/**
 * @file
 * Behaviors for the form math custom element.
 */

((Drupal, math) => {
  Drupal.behaviors.formMathElementCalculator = {
    attach: () => {
      const previousValue = {};

      const updateResult = (el, value) =>{
        if (el.tagName === 'INPUT') {
          el.value = value;
          el.dispatchEvent(new Event('change'));
          return;
        }
        const markupEl = el.querySelector('.form-math-markup-element');
        if (markupEl === null) {
          return;
        }
        const expressionEvaluated = markupEl
          .querySelector('.js-math-result-base')
          .innerHTML.replace('[RESULT]', value);

        markupEl.querySelector('.js-math-result-input').value = expressionEvaluated;
        markupEl.querySelector('.js-math-result').innerHTML = expressionEvaluated;
        if (value !== "") {
          markupEl.classList.add('form-math-markup-element-calculated');
        }
        else {
          markupEl.classList.remove('form-math-markup-element-calculated');
        }
      }

      const calc = (fieldElement) => {
        const fields = fieldElement.dataset.evaluateFields.split(' ');
        const expression = fieldElement.dataset.evaluateExpression;
        const formContext = fieldElement.dataset.evaluateContext;
        const deepFields = JSON.parse(fieldElement.dataset.evaluateDeepFields || "{}");
        const fieldEvaluateRound = fieldElement.dataset.evaluateRound || null;

        const buildExpression = (exp, field) => {
          const currentElement = document.querySelector(`input[name="${field}"], select[name="${field}"]`);
          let currentFieldValue;
          if (currentElement === null && deepFields[field] !== undefined) {
            currentFieldValue = deepFields[field];
          }
          else {
            currentFieldValue = currentElement.value;
          }
          if (currentFieldValue !== '') {
            return exp.replaceAll(`:${field}`, currentFieldValue);
          }
          return exp;
        }

        const handleFieldChange = (e) => {
          // If the value was clear. Rollback the element to the initial state.
          if (e.target.value === "" && previousValue[e.target.name] !== undefined && previousValue[e.target.name] !== "") {
            updateResult(fieldElement, "");
            return;
          }

          const convertedExpression = fields.reduce(buildExpression, expression);
          if (convertedExpression.split(':').length === 1) {
            let expressionResult = math.evaluate(convertedExpression);
            if (fieldEvaluateRound !== null) {
              expressionResult = parseFloat(expressionResult).toFixed(fieldEvaluateRound)
            }
            updateResult(fieldElement, expressionResult);
          }
          previousValue[e.target.name] = e.target.value;
        }

        let selectorFormContext = '';
        if (formContext !== '') {
          selectorFormContext = `form#${formContext} `;
        }
        fields.forEach(name => {
          const elementSelector = `${selectorFormContext}input[name="${name}"], select[name="${name}"]`;
          const element = document.querySelector(elementSelector);
          if (element) {
            element.removeEventListener('change', handleFieldChange);
            element.addEventListener('change', handleFieldChange);
          }
        });
      }

      const formMathElements = document
        .querySelectorAll('.js-form-math-element:not(.built)');
      if (formMathElements.length === 0) {
        return;
      }
      formMathElements.forEach(el => {
          if (
            el.dataset.evaluateFields !== undefined &&
            el.dataset.evaluateExpression !== undefined
          ) {
            try {
              calc(el);
            }
            catch (e) {
              console.error(`Failed to calculate ${e}`);
            }
          }
        });
    },
  }
})(Drupal, math);
