<?php

namespace Drupal\calculation_fields_example\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a calculation_fields form.
 */
class ExampleForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'calculation_fields_example';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['first_value'] = [
      '#type' => 'textfield',
      '#title' => $this->t('First value'),
      '#required' => TRUE,
    ];

    $form['second_value'] = [
      '#type' => 'number',
      '#title' => $this->t('Second value'),
      '#required' => TRUE,
      '#min' => 0,
      '#max' => 2000,
    ];

    $form['third_value'] = [
      '#type' => 'number',
      '#title' => $this->t('third value'),
      '#required' => TRUE,
      '#min' => 0,
      '#max' => 2000,
    ];

    $form['multiple'] = [
      '#type' => 'select',
      '#title' => $this->t('Multiple'),
      '#options' => [
        1 => 1,
        2 => 2,
        3 => 3,
      ],
      '#required' => TRUE,
      '#min' => 0,
      '#max' => 2000,
    ];

    $form['result'] = [
      '#type' => 'form_element_math',
      '#title' => $this->t('Result'),
      '#required' => TRUE,
      '#evaluation_fields' => '(:first_value + :second_value + :third_value) * :multiple',
      '#evaluation_round' => 2,
    ];

    $form['result_markup'] = [
      '#type' => 'form_element_markup_math',
      '#evaluation_fields' => '<h3>This is my test result divided by 2: R$ <span>{{ ((:first_value + :second_value + :third_value) * :multiple) / 2 }}</span></h3>',
      '#evaluation_text_preview' => $this->t('With preview markup'),
      '#evaluation_round' => 2,
    ];

    $form['result_markup_1'] = [
      '#type' => 'form_element_markup_math',
      '#evaluation_fields' => '<h3>This is my test result: R$ <span>{{ (:first_value + :second_value + :third_value) * :multiple }}</span></h3>',
      '#evaluation_round' => 2,
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    foreach (['result', 'result_markup', 'result_markup_1'] as $key) {
      $this->messenger()->addStatus($this->t('The result submitted was: ' . $form_state->getValue($key)));
    }
  }

}
