<?php

namespace Drupal\webform_calculation_fields\Plugin\WebformElement;

use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\User;
use Drupal\webform\Plugin\WebformElement\Number;

/**
 * Provides a Webform Math element.
 *
 * @WebformElement(
 *   id = "form_element_math",
 *   label = @Translation("Field calculator"),
 *   description = @Translation("Provides a math element capable to evaluate math expressions."),
 *   category = @Translation("Calculator"),
 * )
 */
class WebformFieldCalculator extends Number {

  /**
   * {@inheritDoc}
   */
  public function defineDefaultProperties() {
    return parent::defineDefaultProperties() + [
      'evaluation_fields' => '',
      'evaluation_round' => NULL,
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    $form['options']['calculator'] = [
      '#type' => 'details',
      '#title' => 'Calculator settings',
      '#weight' => -1,
    ];

    $form['options']['calculator']['evaluation_round'] = [
      '#type' => 'number',
      '#min' => 0,
      '#title' => $this->t('Round result'),
      '#description' => $this->t('How many decimal cases display'),
      '#weight' => 1,
    ];

    $form['options']['calculator']['evaluation_fields'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Add here the expression'),
      '#description' => $this->t('Example of expressions: field_1 + field_2 - (field_1 * field_3)'),
      '#weight' => 2,
    ];
    return $form;
  }

}
