<?php

namespace Drupal\webform_calculation_fields\Plugin\WebformElement;

use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Plugin\WebformElement\TextField;

/**
 * Provides a Webform Math element.
 *
 * @WebformElement(
 *   id = "form_element_markup_math",
 *   label = @Translation("Field calculator markup"),
 *   description = @Translation("Provided an advance markup that can evaluate expression inside {{ }} tags."),
 *   category = @Translation("Calculator"),
 * )
 */
class WebformMathMarkupElement extends TextField {

  /**
   * {@inheritDoc}
   */
  public function defineDefaultProperties() {
    $default = parent::defineDefaultProperties();
    $custom = [
      'evaluation_round' => NULL,
      'evaluation_fields' => '',
      'evaluation_text_preview' => '',
    ];
    return array_merge(
      $default,
      $custom
    );
  }

  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    unset($form["summary_attributes"]);
    unset($form["validation"]);
    unset($form["element_description"]);
    unset($form["form"]);
//    unset($form["element"]);


    $form['markup']['evaluation_fields'] = [
      '#type' => 'webform_html_editor',
      '#title' => $this->t('HTML markup'),
      '#description' => $this->t('Enter custom HTML into your webform. Add the expression between {{ }}. Like {{ :field_x + :field_y }}'),
    ];

    $form['markup']['evaluation_round'] = [
      '#type' => 'number',
      '#min' => 0,
      '#title' => $this->t('Round result'),
      '#description' => $this->t('How many decimal cases display'),
      '#weight' => 1,
    ];

    $form['markup']['evaluation_text_preview'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Add the preview text'),
      '#description' => $this->t('Text that be displayed until all inputs used by this field be populated. If not provided the element will displayed when the calculate is finished.'),
      '#weight' => 2,
    ];
    return $form;
  }

}
